.. edittag documentation master file, created by
   sphinx-quickstart on Sat Jan 22 09:04:05 2011.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to edittag's documentation!
===================================

Contents:

.. toctree::
   :maxdepth: 2
   
   introduction
   installation
   design
   validation
   formatting
   using_adapters
   using_primers
   helpers
   license
   citation
   funding
   references

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

